calc.EBIC
calculates the EBIC from the sequence of lambda values in glmnet objects.
node.est
Subroutine in mgmfit for neighborhood regression at each node.
potts_parameter
Translate provided edge weights in mgmsampler into a paramter matrix. The details are in the help file for mgmsampler.
VARreshape
Reshapes data in a lag-1 VAR format.